@@ -1,3 +1,4 @@
+use ::std::iter::IntoIterator;
 use ::std::ops::Add;
 use ::std::ops::AddAssign;
 use ::std::ops::Div;
@@ -18,6 +19,7 @@ use ::num_traits::sign::Signed;
 use crate::num::FromRounded;
 use crate::num::INum;
 use crate::num::Num;
+use crate::num::NumIdentity;
 use crate::num::ToRounded;
 use crate::num::ToSignedClamped;
 
@@ -31,6 +33,9 @@ use crate::geom::Transform;
 
 use crate::Random;
 
+mod line_iterator;
+pub use self::line_iterator::LineIterator;
+
 #[derive(Copy, Clone, Debug, PartialEq)]
 pub struct Line<N: Num = f32>(pub Point<N>, pub Point<N>);
 
@@ -328,6 +333,18 @@ impl<N: Num> Line<N> {
     pub fn flip(self) -> Self {
         Self(self.end(), self.start())
     }
+
+    pub fn into_iter_with_step(self, step: N) -> LineIterator<N> {
+        LineIterator::new(self, step, true)
+    }
+
+    pub fn into_iter_inclusive(self) -> LineIterator<N> {
+        LineIterator::new(self, <N as NumIdentity>::one(), false)
+    }
+
+    pub fn into_iter_inclusive_with_step(self, step: N) -> LineIterator<N> {
+        LineIterator::new(self, step, false)
+    }
 }
 
 impl<N: Num + Signed> Line<N> {
@@ -686,6 +703,15 @@ impl<N: Num> Into<(Point<N>, Point<N>)> for Line<N> {
     }
 }
 
+impl<N: Num> IntoIterator for Line<N> {
+    type Item = Point<N>;
+    type IntoIter = LineIterator<N>;
+
+    fn into_iter(self) -> Self::IntoIter {
+        LineIterator::new(self, <N as NumIdentity>::one(), true)
+    }
+}
+
 #[cfg(test)]
 mod is_horizontal {
     use super::*;
